==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-fancymenu/translations/fancymenu_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Zobrazit/skrýt hlavní nabídku</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="55"/>
        <source>All Applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Text tlačítka:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Uživatelsky určená velikost písma:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> bodů</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Soubor s nabídkou</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Soubor s nabídkou:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Klávesová zkratka</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Klávesovou zkratku zaznamenáte kliknutím na tlačítko:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Při dalším zobrazení nabídky vyčistit hledání</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Vrátit na výchozí</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Vybrat soubor s ikonou</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Obrázky (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Vybrat soubor s nabídkou</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Soubory s nabídkami (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="153"/>
        <source>Search...</source>
        <translation>Hledat…</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="160"/>
        <source>LXQt Configuration Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="166"/>
        <source>Leave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="172"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="185"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="345"/>
        <source>Add to desktop</source>
        <translation>Přidat na plochu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="353"/>
        <source>Question</source>
        <translation>Dotaz</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="354"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Stejnojmenný soubor už existuje.
Chcete ho přepsat?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="360"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="361"/>
        <source>The file cannot be overwritten.</source>
        <translation>Soubor není možné přepsat.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="368"/>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="381"/>
        <source>Remove from Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="388"/>
        <source>Add to Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="572"/>
        <source>No Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="573"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.0.1.orig.tar.xz: lxqt-panel-2.0.1/plugin-fancymenu/translations/fancymenu_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Zobrazit/skrýt hlavní nabídku</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="55"/>
        <source>All Applications</source>
        <translation>Všechny aplikace</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu settings</source>
        <translation>Nastavení nabídky</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Text tlačítka:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Uživatelsky určená velikost písma:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> bodů</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation type="unfinished">Automaticky vybrat po:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Soubor s nabídkou</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Soubor s nabídkou:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Klávesová zkratka</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Klávesovou zkratku zaznamenáte kliknutím na tlačítko:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Při dalším zobrazení nabídky vyčistit hledání</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Rozvržení</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Pozice řádku tlačítek</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Pozice kategorií</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Vrátit na výchozí</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Nalevo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Napravo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Vybrat soubor s ikonou</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Obrázky (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Vybrat soubor s nabídkou</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Soubory s nabídkami (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation>Hledat…</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="188"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="354"/>
        <source>Add to desktop</source>
        <translation>Přidat na plochu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="362"/>
        <source>Question</source>
        <translation>Dotaz</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="363"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Stejnojmenný soubor už existuje.
Chcete ho přepsat?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="369"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="370"/>
        <source>The file cannot be overwritten.</source>
        <translation>Soubor není možné přepsat.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="377"/>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="390"/>
        <source>Remove from Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="397"/>
        <source>Add to Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="703"/>
        <source>No Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="704"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
